clear
clc
load build.mat
figure(1)
bode(G)
grid on

figure(2)
hsv_add = hankelsv(G);
bar(hsv_add)
title('Hankel Singular Values of the Model (G)');
xlabel('Number of States')
ylabel('Singular Values (\sigma_i)')
line([10.5 10.5],[0 1.5e-3],'Color','r','linestyle','--','linewidth',1)
text(6,1.6e-3,'10 dominant states.')


% Compute 10th-order reduced model (reduce uses balancmr method by default)
[Ga_add,info_add] = reduce(G,10,'Algorithm', 'balance','ErrorType', 'add');
figure(3) 
% Now compare the original model G to the reduced model Gr_add
bode(G,'b',Ga_add,'r'), grid on
title('Comparing Original (G) to the Reduced model (Ga\_add)')
legend('G - 48-state original ','Ga\_add - 10-state reduced','location','northeast')

GG = G;
GG.d = 1e-5;
hsv_mult = hankelsv(GG,'mult');
figure(4)
bar(hsv_mult)
title('Multiplicative-Error Singular Values of the Model (G)');
xlabel('Number of States')
ylabel('Singular Values (\sigma_i)')

% Use bstmr algorithm option for model reduction
[Ga_mult,info_mult] = reduce(GG,10,'algorithm','bst');
figure(5)
%now compare the original model G to the reduced model Gr_mult
bode(G,Ga_add,Ga_mult,{1e-2,1e4}), grid on
title('Comparing Original (G) to the Reduced models (Ga\_add and Ga\_mult)')
legend('G - 48-state original ','Ga\_add (balancmr)','Ga\_mult (bstmr)','location','northeast')

figure(6)
step(G,Ga_add,Ga_mult,15) %step response until 15 seconds
legend('G: 48-state original ','Ga\_add: 10-state (balancmr)','Ga\_mult: 10-state (bstmr)')

e1=norm(G-Ga_add,inf) % actual error
e3=norm(GG\(GG-Ga_mult),inf) % actual error